<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

if (!defined('_PS_VERSION_')) {
    exit;
}

use SmebankPlugin\Handler\OrderCreationHandler;
use SmebankPlugin\Repository\KevinPaymentRepository;
use SmebankPlugin\Utils\OrderHelper;
use SmebankPluginFramework\Application\KevinConstants;

class SmebankConfirmModuleFrontController extends ModuleFrontController
{
    /**
     * @var Smebank
     */
    public $module;

    /**
     * Process confirm request.
     */
    public function postProcess()
    {
        $paymentId = Tools::getValue('paymentId');
        $kevinStatus = Tools::getValue('statusGroup');

        if (!$this->module->isAvailable() || !$paymentId || !$kevinStatus) {
            Tools::redirect($this->context->link->getModuleLink(\Smebank::MODULE_NAME, 'error'));
            return;
        }

        $kevinPaymentRepository = new KevinPaymentRepository();
        $kevinPayment = $kevinPaymentRepository->getByPaymentId($paymentId);

        $cart = $this->context->cart;
        $customer = $this->context->customer;

        if ($orderId = $kevinPayment['id_order']) {
            $order = new Order($orderId);
        } elseif (!$kevinPaymentRepository->tryLockPayment($paymentId)) {
            // THIS IS PREVENTION OF MULTIPLE ORDERS CREATION
            // if payment couldnt be locked by this process it means that some other process is already trying to create order
            $orderId = null;
            $i = 0;
            while (!$orderId) {
                if ($i > 5) {
                    Tools::redirect($this->context->link->getModuleLink(\Smebank::MODULE_NAME, 'error'));
                    return;
                }
                $orderId = OrderHelper::getOrderIdByCartId($cart->id);
                sleep(2);
                $i++;
            }

            $order = new Order($orderId);
        } else {

            if ($cart->id != $kevinPayment['id_cart'] || $customer->id != $cart->id_customer) {
                Tools::redirect($this->context->link->getModuleLink(\Smebank::MODULE_NAME, 'error'));
                return;
            }

            if ($kevinStatus === KevinConstants::STATUS_GROUP_FAILED) {
                Tools::redirect($this->context->link->getModuleLink(\Smebank::MODULE_NAME, 'error', ['type' => 'payment-failed']));
                return;
            }
            if ($kevinStatus === KevinConstants::STATUS_GROUP_STARTED) {
                Tools::redirect($this->context->link->getModuleLink(\Smebank::MODULE_NAME, 'error', ['type' => 'payment-canceled']));
                return;
            }

            $handler = new OrderCreationHandler($this->module, $kevinPaymentRepository);

            try {
                $order = $handler->handle($cart, $kevinPayment['payment_id']);
            } catch (\Exception $e) {
                Tools::redirect($this->context->link->getModuleLink(\Smebank::MODULE_NAME, 'error'));
                return;
            }
        }

        if ($customer->id != $order->id_customer) {
            Tools::redirect($this->context->link->getModuleLink(\Smebank::MODULE_NAME, 'error'));
            return;
        }

        $params = [
            'id_cart' => $order->id_cart,
            'id_module' => $this->module->id,
            'id_order' => $order->id,
            'key' => $customer->secure_key,
            'statusGroup' => Tools::getValue('statusGroup'),
        ];

        Tools::redirect($this->context->link->getPageLink('order-confirmation', null, null, $params));
    }
}
