<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

if (!defined('_PS_VERSION_')) {
    exit;
}

use SmebankPlugin\Handler\PaymentInitiationHandler;
use SmebankPlugin\Repository\KevinPaymentRepository;

class SmebankRedirectModuleFrontController extends ModuleFrontController
{
    /**
     * @var Smebank
     */
    public $module;

    public function __construct()
    {
        parent::__construct();
        $this->display_column_left = false;
        $this->display_column_right = false;
    }

    /**
     * Process redirect request.
     */
    public function postProcess()
    {
        $gateway = $this->module->getGateway();
        $gatewaySettings = $this->module->getGatewaySettings();

        if (!$this->module->isAvailable()) {
            Tools::redirect($this->context->link->getModuleLink(\Smebank::MODULE_NAME, 'error'));
        }

        $bankId = Tools::getValue('id');

        if (!$gatewaySettings->isCheckoutViewFrame() && !$bankId) {
            $this->context->cookie->__set('kevin_error_no_bank', 1);
            Tools::redirect($this->context->link->getPageLink('order'));
        }

        $cart = $this->context->cart;

        if (!Validate::isLoadedObject($cart) || $cart->OrderExists() === true) {
            Tools::redirect($this->context->link->getModuleLink(\Smebank::MODULE_NAME, 'error'));
        }

        $handler = new PaymentInitiationHandler($gateway, $gatewaySettings, new KevinPaymentRepository());
        $result = $handler->handle($cart, $bankId);

        if (!$result) {
            Tools::redirect($this->context->link->getModuleLink(\Smebank::MODULE_NAME, 'error'));
        }

        Tools::redirect($result);
    }
}
