<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

namespace SmebankPlugin\Form\Settings\Subform;

if (!defined('_PS_VERSION_')) {
    exit;
}

use SmebankPlugin\GatewaySettings;
use SmebankPlugin\Utils\Translator;
use SmebankPluginFramework\Presentation\Admin\Form\BuildGuideline\CheckoutSettingsFormBuildGuideline;
use SmebankPluginFramework\Presentation\Admin\Form\BuildGuideline\FormFieldBuildGuideline;
use SmebankPluginFramework\Presentation\Admin\Form\BuildGuideline\MainSettingsFormBuildGuideline;

class FormFieldBuilder
{
    /**
     * @param FormFieldBuildGuideline $guideline
     *
     * @return FormField
     */
    public static function buildFromGuideline(FormFieldBuildGuideline $guideline)
    {
        $formField = new FormField(self::mapName($guideline), $guideline->getType());
        $formField->setLabel(Translator::translate($guideline->getTitle()));
        $formField->setPlaceholder(Translator::translate($guideline->getPlaceholder()));
        $formField->setDescription(Translator::translate($guideline->getDescription()));
        $formField->setValidators($guideline->getValidators());
        $formField->setRequired($guideline->isRequired());
        $formField->setDefault(Translator::translate($guideline->getDefault()));

        if ($guideline->getType() === $guideline::FIELD_TYPE_SELECT) {
            $options = [
                'query' => [],
                'id' => 'id_option',
                'name' => 'name',
            ];
            foreach ($guideline->getOptions() as $key => $value) {
                $options['query'][] = [
                    'id_option' => $key,
                    'name' => Translator::translate($value),
                ];
            }

            $formField->setOptions($options);
        }

        return $formField;
    }

    /**
     * @param FormFieldBuildGuideline $guideline
     *
     * @return string
     *
     * @throws \Exception
     */
    private static function mapName($guideline)
    {
        switch ($guideline->getName()) {
            case CheckoutSettingsFormBuildGuideline::FIELD_NAME_BANK_SEARCH:
                return GatewaySettings::SMEBANK_BANK_SEARCH;
            case CheckoutSettingsFormBuildGuideline::FIELD_NAME_COUNTRY_DROPDOWN:
                return GatewaySettings::SMEBANK_COUNTRY_DROPDOWN;
            case CheckoutSettingsFormBuildGuideline::FIELD_NAME_CHECKOUT_VIEW:
                return GatewaySettings::SMEBANK_CHECKOUT_VIEW;
            case MainSettingsFormBuildGuideline::FIELD_NAME_ENABLED:
                return GatewaySettings::SMEBANK_ENABLED;
            case MainSettingsFormBuildGuideline::FIELD_NAME_ENDPOINT_CREDITOR_NAME:
                return GatewaySettings::SMEBANK_CREDITOR_NAME;
            case MainSettingsFormBuildGuideline::FIELD_NAME_ENDPOINT_CREDITOR_ACCOUNT:
                return GatewaySettings::SMEBANK_CREDITOR_ACCOUNT;
            case MainSettingsFormBuildGuideline::FIELD_NAME_ENDPOINT_SECRET:
                return GatewaySettings::SMEBANK_ENDPOINT_SECRET;
            case MainSettingsFormBuildGuideline::FIELD_NAME_CLIENT_SECRET:
                return GatewaySettings::SMEBANK_CLIENT_SECRET;
            case MainSettingsFormBuildGuideline::FIELD_NAME_CLIENT_ID:
                return GatewaySettings::SMEBANK_CLIENT_ID;
            default:
                throw new \Exception('Undefined form field');
        }
    }
}
