<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

namespace SmebankPlugin\Form\Settings\Subform;

if (!defined('_PS_VERSION_')) {
    exit;
}

use SmebankPlugin\Utils\Translator;
use SmebankPluginFramework\Presentation\Admin\Form\BuildGuideline\MainSettingsFormBuildGuideline;

class MainSettingsSubform implements SubformInterface
{
    const SUBMIT_NAME = 'submitMainSettings';

    /**
     * @var MainSettingsFormBuildGuideline
     */
    private $buildGuideline;

    /**
     * @var FormField
     */
    private $formFields;

    public function __construct(MainSettingsFormBuildGuideline $buildGuideline)
    {
        $this->buildGuideline = $buildGuideline;
        $this->initFormFields();
    }

    public function toArray()
    {
        $formFields = [];
        foreach ($this->formFields as $formField) {
            $formFields[] = $formField->toArray();
        }

        return [
            'form' => [
                'legend' => [
                    'title' => Translator::translate($this->buildGuideline->getName()),
                    'icon' => 'icon-cogs',
                ],
                'input' => $formFields,
                'submit' => [
                    'title' => Translator::translate('Save'),
                    'name' => self::SUBMIT_NAME,
                ],
            ],
        ];
    }

    public function getFormFields()
    {
        return $this->formFields;
    }

    public function getSubmitName()
    {
        return self::SUBMIT_NAME;
    }

    private function initFormFields()
    {
        foreach ($this->buildGuideline->getFormFieldBuildGuidelines() as $formFieldBuildGuideline) {
            $formField = FormFieldBuilder::buildFromGuideline($formFieldBuildGuideline);
            if ($formFieldBuildGuideline->getName() === MainSettingsFormBuildGuideline::FIELD_NAME_ENABLED) {
                $formField->setLabel(Translator::translate($formFieldBuildGuideline->getLabel()));
            }
            $this->formFields[] = $formField;
        }
    }
}
