<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

namespace SmebankPlugin\Handler;

if (!defined('_PS_VERSION_')) {
    exit;
}

use SmebankPlugin\Gateway;
use SmebankPlugin\Repository\KevinPaymentRepository;
use SmebankPlugin\Repository\KevinRefundRepository;
use SmebankPlugin\Utils\Url;
use SmebankPluginFramework\Application\Exception\KevinRequestException;
use Order;

class RefundHandler
{
    /**
     * @var Gateway
     */
    private $gateway;
    /**
     * @var KevinPaymentRepository
     */
    private $kevinPaymentRepository;
    /**
     * @var KevinRefundRepository
     */
    private $kevinRefundRepository;

    public function __construct(Gateway $gateway, KevinPaymentRepository $kevinPaymentRepository, KevinRefundRepository $kevinRefundRepository)
    {
        $this->gateway = $gateway;
        $this->kevinPaymentRepository = $kevinPaymentRepository;
        $this->kevinRefundRepository = $kevinRefundRepository;
    }

    public function handle($refundAmount, Order $order, $formToken)
    {
        $kevinPayment = $this->kevinPaymentRepository->getByOrderId($order->id);
        $paymentId = $kevinPayment['payment_id'];

        $refundAmount = number_format($refundAmount, 2);

        $refundAttributes = [
            'amount' => $refundAmount,
            'Webhook-URL' => Url::getWebhookUrl(),
        ];

        try {
            if (!$this->kevinRefundRepository->add($order->id, $paymentId, $refundAmount, $formToken)) {
                return false;
            }

            $refundResponse = $this->gateway->initPaymentRefund($kevinPayment['payment_id'], $refundAttributes);
        } catch (KevinRequestException $e) {
            $this->kevinRefundRepository->updateWithKevinError($formToken, $e->getMessage());
            return false;
        }

        if (!$refundResponse) {
            $this->kevinRefundRepository->updateWithKevinError($formToken, '');
            return false;
        }

        $this->kevinRefundRepository->updateWithKevinResponse($formToken, $refundResponse);

        return true;
    }
}
