<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

namespace SmebankPlugin\Handler;

if (!defined('_PS_VERSION_')) {
    exit;
}

use Configuration;
use SmebankPlugin\GatewaySettings;
use SmebankPlugin\Repository\KevinPaymentRepository;
use SmebankPlugin\Repository\KevinRefundRepository;
use SmebankPlugin\Repository\PsOrderRepository;
use Order;
use OrderHistory;
use Validate;

class RefundWebhookHandler implements WebhookHandlerInterface
{
    /**
     * @var GatewaySettings
     */
    private $gatewaySettings;
    /**
     * @var KevinRefundRepository
     */
    private $kevinRefundRepository;
    /**
     * @var PsOrderRepository
     */
    private $psOrderRepository;
    /**
     * @var KevinPaymentRepository
     */
    private $kevinPaymentRepository;

    public function __construct(
        GatewaySettings $gatewaySettings,
        KevinRefundRepository $kevinRefundRepository,
        KevinPaymentRepository $kevinPaymentRepository,
        PsOrderRepository $psOrderRepository)
    {
        $this->gatewaySettings = $gatewaySettings;
        $this->kevinRefundRepository = $kevinRefundRepository;
        $this->psOrderRepository = $psOrderRepository;
        $this->kevinPaymentRepository = $kevinPaymentRepository;
    }

    public function handle($request)
    {
        $paymentId = $request['paymentId'];
        $kevinPayment = $this->kevinPaymentRepository->getByPaymentId($paymentId);
        $order = new Order($kevinPayment['id_order']);

        if (!Validate::isLoadedObject($order)) {
            return [
                'isSuccess' => false,
                'message' => 'Order not found.',
            ];
        }

        $this->kevinRefundRepository->updateRefundStatus($request['id'], $request['statusGroup']);

        $refundStateId = (int) Configuration::get('PS_OS_REFUND');
        if (!$this->psOrderRepository->isOrderStateInHistory($order->id, $refundStateId)) {
            $orderDetailList = $order->getOrderDetailList();
            $productsNotRefunded = 0;
            foreach ($orderDetailList as $orderDetail) {
                $productsNotRefunded += $orderDetail['product_quantity'] - $orderDetail['product_quantity_refunded'];
            }

            $newOrderStatus = $productsNotRefunded > 0 ? $this->gatewaySettings->getOrderStatusKevinPartialRefundId() : $refundStateId;

            $orderHistory = new OrderHistory();
            $orderHistory->id_order = (int) $order->id;
            $orderHistory->changeIdOrderState($newOrderStatus, $order, true);
            $orderHistory->addWithemail();
        }

        return [
            'isSuccess' => true,
            'message' => 'Signatures match.',
        ];
    }
}
