<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

namespace SmebankPlugin;

use Tools;

if (!defined('_PS_VERSION_')) {
    exit;
}

class PluginConfig
{
    /**
     * @return string|null
     */
    public static function PLUGIN_VERSION()
    {
        return self::getValue('plugin_version');
    }

    /**
     * @return string|null
     */
    public static function CUSTOM_WEBHOOK_URL()
    {
        return self::getValue('custom_webhook_url');
    }

    /**
     * @return string|null
     */
    public static function SMEBANK_API_DOMAIN()
    {
        return self::getValue('api_sme_domain');
    }

    /**
     * @return string
     */
    public static function SMEBANK_MONITORING_SERVICE_URL()
    {
        return self::getValue('monitoring_service_url');
    }

    /**
     * @return string
     */
    public static function SMEBANK_MONITORING_SERVICE_KEY()
    {
        return self::getValue('monitoring_service_key');
    }

    /**
     * @param $key
     *
     * @return mixed|null
     */
    private static function getValue($key)
    {
        static $config;
        if (!$config) {
            $config = json_decode(Tools::file_get_contents(__DIR__ . '/../smebank.config.json'), true);
            if (file_exists(__DIR__ . '/../smebank.config.dev.json')) {
                $localConfig = json_decode(Tools::file_get_contents(__DIR__ . '/../smebank.config.dev.json'), true);
                $config = array_merge($config, $localConfig);
            }
            if (file_exists(__DIR__ . '/../smebank.config.local.json')) {
                $localConfig = json_decode(Tools::file_get_contents(__DIR__ . '/../smebank.config.local.json'), true);
                $config = array_merge($config, $localConfig);
            }
        }

        return isset($config[$key]) ? $config[$key] : null;
    }
}
