<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

namespace SmebankPlugin\Repository;

if (!defined('_PS_VERSION_')) {
    exit;
}

use Db;
use SmebankPluginFramework\Application\KevinConstants;

class KevinRefundRepository
{
    /**
     * @var Db
     */
    private $db;

    public function __construct()
    {
        $this->db = Db::getInstance();
    }

    /**
     * @param $orderId
     * @param $paymentId
     * @param $amount
     * @param $formToken
     *
     * @return bool
     *
     * @throws \PrestaShopDatabaseException
     */
    public function add($orderId, $paymentId, $amount, $formToken)
    {
        return $this->db->insert('kevin_refund', [
            'id_order' => (int) $orderId,
            'payment_id' => pSQL($paymentId),
            'amount' => (float)$amount,
            'form_token' => pSQL($formToken),
            'created_at' => (new \DateTime())->format('Y-m-d H:i:s'),
        ]);
    }

    public function updateWithKevinError($formToken, $error)
    {
        $updateData = [
            'status_group' => pSQL(KevinConstants::STATUS_GROUP_FAILED),
            'error' => pSQL($error),
        ];
        $this->db->update('kevin_refund', $updateData, 'form_token = \'' . pSQL($formToken) . '\'');
    }

    public function updateWithKevinResponse($formToken, $kevinResponse)
    {
        $updateData = [
            'status_group' => pSQL($kevinResponse['statusGroup']),
            'refund_id' => pSQL($kevinResponse['id']),
        ];
        $this->db->update('kevin_refund', $updateData, 'form_token = \'' . pSQL($formToken) . '\'');
    }

    public function updateRefundStatus($refundId, $status)
    {
        $this->db->update('kevin_refund', ['status_group' => $status], 'refund_id = \'' . pSQL($refundId) . '\'');
    }

    public function getAllByPaymentId($paymentId)
    {
        $sql = 'SELECT * FROM ' . _DB_PREFIX_ . 'kevin_refund WHERE payment_id = \'' . pSQL($paymentId) . '\'';
        $row = Db::getInstance()->executeS($sql);

        return $row ?: [];
    }

    /**
     * @param $orderId
     *
     * @return float
     *
     * @throws \PrestaShopDatabaseException
     */
    public function getSumRefundsForOrder($orderId)
    {
        $orderId = pSQL($orderId);
        $sql = 'SELECT SUM(amount) as sum FROM ' . _DB_PREFIX_ . "kevin_refund WHERE id_order = '$orderId' AND status_group IN ('started','pending','completed');";
        $row = Db::getInstance()->executeS($sql);

        return (float) (isset($row[0]['sum']) ? $row[0]['sum'] : 0);
    }
}
