<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

namespace SmebankPlugin\View;

if (!defined('_PS_VERSION_')) {
    exit;
}

use Context;
use Currency;
use SmebankPlugin\Utils\Translator;
use Tools;

class AdminOrderKevinTabView
{
    /**
     * @var \Order
     */
    private $order;
    /**
     * @var array
     */
    private $kevinPayment;
    /**
     * @var array
     */
    private $kevinRefunds;

    public function __construct(\Order $order, array $kevinPayment, array $kevinRefunds)
    {
        $this->order = $order;
        $this->kevinPayment = $kevinPayment;
        $this->kevinRefunds = $kevinRefunds;
    }

    public function html(\Smebank $module)
    {
        foreach ($this->kevinRefunds as $index => $kevinRefund) {
            $this->kevinRefunds[$index]['amount'] = Tools::displayPrice($kevinRefund['amount'], new Currency((int) $this->order->id_currency));
        }

        if ($this->kevinPayment['payment_type'] === 'card') {
            $paymentType = Translator::translate('Credit/Debit card');
        } elseif ($this->kevinPayment['payment_type']) {
            $bankName = null;
            if ($gateway = $module->getGateway()) {
                $bank = $gateway->getKevinBank($this->kevinPayment['payment_type']);
                $bankName = isset($bank['name']) ? $bank['name'] : null;
            }
            $paymentType = Translator::translate('Bank');
            $paymentType .= $bankName ? " ($bankName)" : ' (' . $this->kevinPayment['payment_type'] . ')';
        } else {
            $paymentInfo = null;
            if ($gateway = $module->getGateway()) {
                $paymentResponse = $gateway->getPayment($this->kevinPayment['payment_id']);
                if (isset($paymentResponse['bankPaymentMethod']['bankId'])) {
                    $bank = $gateway->getKevinBank($paymentResponse['bankPaymentMethod']['bankId']);
                    $paymentInfo = isset($bank['name']) ? $bank['name'] : null;
                } elseif (isset($paymentResponse['cardPaymentMethod'])) {
                    $paymentInfo = Translator::translate('Credit/Debit card');
                }
            }
            $paymentType = Translator::translate('Redirect to bank selection');
            if ($paymentInfo) {
                $paymentType .= " ($paymentInfo)";
            }
        }

        Context::getContext()->smarty->assign([
            'text_payment_id' => sprintf(Translator::translate('Payment ID is: %s'), $this->kevinPayment['payment_id']),
            'text_cart_id' => 'CART ID: ' . $this->kevinPayment['id_cart'],
            'text_payment_status' => $this->kevinPayment['status_group'] ?
                sprintf(Translator::translate('Payment status is: %s'), $this->kevinPayment['status_group']) : null,
            'payment_date' => $this->kevinPayment['created_at'],
            'payment_type' => $paymentType,
            'text_refunds' => Translator::translate('Refunds'),
            'kevin_refunds' => $this->kevinRefunds,
        ]);

        return $module->display(\Smebank::MODULE_FILE, 'views/templates/hook/admin_order_content_ship.tpl');
    }
}
