<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

namespace SmebankPlugin\View;

use Context;
use SmebankPlugin\Utils\Translator;
use SmebankPluginFramework\Application\KevinConstants;

class OrderConfirmationView
{
    /**
     * @var Context
     */
    private $context;
    /**
     * @var string
     */
    private $kevinStatus;

    public function __construct($kevinStatus)
    {
        $this->context = Context::getContext();
        $this->kevinStatus = $kevinStatus;
    }

    public function html(\Smebank $module)
    {
        switch ($this->kevinStatus) {
            case KevinConstants::STATUS_GROUP_FAILED:
                $type = 'error';
                $message = Translator::translate('Your order cannot be processed because the bank declined your transaction. Please try again.');
                break;
            case KevinConstants::STATUS_GROUP_STARTED:
                $type = 'error';
                $message = Translator::translate('Payment initiation was cancelled.');
                break;
            case KevinConstants::STATUS_GROUP_PENDING:
                $type = 'warning';
                $message = Translator::translate('We will start processing your order once your payment is received.');
                break;
            case KevinConstants::STATUS_GROUP_COMPLETED:
                $type = 'success';
                $message = Translator::translate('Thank you for your payment. Your transaction has been completed. You will receive an email with the receipt of your purchase.');
                break;
            default:
                $type = 'error';
                $message = Translator::translate('Sorry, something went wrong');
                break;
        }

        $this->context->smarty->assign(['type' => $type, 'message' => $message]);

        return $module->display(\Smebank::MODULE_FILE, 'views/templates/hook/order_confirmation.tpl');
    }
}