<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */


namespace SmebankPluginFramework\Application;

use Kevin\KevinException;
use SmebankPluginFramework\Application\Exception\KevinRequestBadRequestException;
use SmebankPluginFramework\Application\Exception\KevinRequestException;
use SmebankPluginFramework\Application\Exception\KevinRequestInternalServerException;
use SmebankPluginFramework\Application\Exception\KevinRequestUnauthorizedException;

class PaymentClientRequestExceptionFactory
{
    /**
     * @param KevinException $e
     * @return KevinRequestBadRequestException|KevinRequestException|KevinRequestInternalServerException|KevinRequestUnauthorizedException
     */
    public static function createFromKevinException($e)
    {
        if ($e->getCode() === 401) {
            return new KevinRequestUnauthorizedException($e);
        }
        if ($e->getCode() >= 400 && $e->getCode() < 500) {
            return new KevinRequestBadRequestException($e);
        }
        if ($e->getCode() >= 500 && $e->getCode() < 600) {
            return new KevinRequestInternalServerException($e);
        }

        return new KevinRequestException($e);
    }

}
