<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */


namespace SmebankPluginFramework\Application;

use SmebankPluginFramework\Application\Exception\KevinInitException;

class PaymentClientSettings
{
    private $pluginVersion;
    private $pluginPlatform;
    private $pluginPlatformVersion;
    private $domain;
    private $lang;
    private $version;

    public function __construct(
        $pluginVersion,
        $pluginPlatform,
        $pluginPlatformVersion,
        $domain = null,
        $lang = null
    )
    {
		if (!$pluginVersion || !$pluginPlatform || !$pluginPlatformVersion) {
			throw new KevinInitException('missing settings param');
		}
        $this->pluginVersion = $pluginVersion;
        $this->pluginPlatform = $pluginPlatform;
        $this->pluginPlatformVersion = $pluginPlatformVersion;
        $this->domain = $domain;
        $this->lang = $lang;
        $this->version = '0.3';
    }

    /**
     * @return array
     */
    public function toArray()
    {
        return [
            'pluginVersion' => $this->pluginVersion,
            'pluginPlatform' => $this->pluginPlatform,
            'pluginPlatformVersion' => $this->pluginPlatformVersion,
            'domain' => $this->domain,
            'lang' => $this->lang,
            'version' => $this->version
        ];
    }
}
