<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */


namespace SmebankPluginFramework\Presentation\Admin\Form\BuildGuideline;

class PaymentStatusesFormBuildGuideline implements FormBuildGuidelineInterface
{
    const FIELD_NAME_NEW_PAYMENT_STATUS = 'payment_new_order_status';
    const FIELD_NAME_PENDING_PAYMENT_STATUS = 'payment_pending_order_status';
    const FIELD_NAME_COMPLETED_PAYMENT_STATUS = 'payment_completed_order_status';
    const FIELD_NAME_FAILED_PAYMENT_STATUS = 'payment_failed_order_status';

    private $name = 'Order statuses';

    /**
     * @var array
     */
    private $guidelines;

    public function __construct()
    {
        $this->guidelines = [
            self::FIELD_NAME_NEW_PAYMENT_STATUS => (new FormFieldBuildGuideline())
                ->setName(self::FIELD_NAME_NEW_PAYMENT_STATUS)
                ->setTitle('Payment started')
                ->setType(FormFieldBuildGuideline::FIELD_TYPE_SELECT)
                ->setDescription('Select order status for started payment'),
            self::FIELD_NAME_PENDING_PAYMENT_STATUS => (new FormFieldBuildGuideline())
                ->setName(self::FIELD_NAME_PENDING_PAYMENT_STATUS)
                ->setTitle('Payment pending')
                ->setType(FormFieldBuildGuideline::FIELD_TYPE_SELECT)
                ->setDescription('Select order status for pending payment'),
            self::FIELD_NAME_COMPLETED_PAYMENT_STATUS => (new FormFieldBuildGuideline())
                ->setName(self::FIELD_NAME_COMPLETED_PAYMENT_STATUS)
                ->setTitle('Payment completed')
                ->setType(FormFieldBuildGuideline::FIELD_TYPE_SELECT)
                ->setDescription('Select order status for completed payment'),
            self::FIELD_NAME_FAILED_PAYMENT_STATUS => (new FormFieldBuildGuideline())
                ->setName(self::FIELD_NAME_FAILED_PAYMENT_STATUS)
                ->setTitle('Payment failed')
                ->setType(FormFieldBuildGuideline::FIELD_TYPE_SELECT)
                ->setDescription('Select order status for failed payment'),
        ];
    }

    public function getFormFieldBuildGuidelines()
    {
        return $this->guidelines;
    }

    public function getName()
    {
        return $this->name;
    }
}
