/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

try {
	$(document).ready(function () {

		var prestashopRefundButton = $('button[name=partialRefund]');
		if (prestashopRefundButton.length) {
			var prestashopPartialRefundProductInputs = $("[name^='partialRefundProduct[']");
			var prestashopPartialRefundShippingCostInput = $("[name='partialRefundShippingCost']");
			var prestashopPartialRefundProductQuantityInputs = $("[name^='partialRefundProductQuantity[']")
			prestashopRefundButton.closest('.partial_refund_fields').prepend(getRefundSmebankSectionHtmlPre176());
		} else {
			var prestashopRefundButton = $('#cancel_product_save');
			var prestashopPartialRefundProductInputs = $("[name^='cancel_product[amount_']")
			var prestashopPartialRefundShippingCostInput = $('#cancel_product_shipping_amount');
			var prestashopPartialRefundProductQuantityInputs = $("[name^='cancel_product[quantity_']")
			$('.refund-checkboxes-container').prepend(getRefundSmebankSectionHtmlPost176())
		}

		prestashopRefundButton.on('click', function () {
			setTimeout(() => {
				if (smebankRefundCheckbox.is(':checked')) {
					disableRefundButton();
				}
			}, 5)
		})

		var smebankRefundCheckbox = $('#refundwithsmebank');
		var smebankRefundAmountInput = $('#refundwithsmebank-amount');
		var smebankRefundAlertExceeds = $('#smebank-refund-alert-exceeds');
		var smebankRefundAlertZero = $('#smebank-refund-alert-zero');
		var smebankRefundAmountWarning = $('#smebank-refund-amount-warning');
		var smebankRefundAmountWarningSpan = $('#smebank-refund-amount-warning-span');

		prestashopPartialRefundProductInputs.on('input', function () {
			checkSmebankRefund();
		})
		prestashopPartialRefundShippingCostInput.on('input', function () {
			checkSmebankRefund();
		})
		smebankRefundCheckbox.on('input', function () {
			checkSmebankRefund();
		})
		prestashopPartialRefundProductQuantityInputs.on('focusout', function () {
			checkSmebankRefund();
		})

		function checkSmebankRefund()
		{
			hideElement(smebankRefundAlertExceeds);
			hideElement(smebankRefundAlertZero);
			hideElement(smebankRefundAmountWarning);

			if (!smebankRefundCheckbox.is(':checked')) {
				enableRefundButton()
				return;
			}

			if (!validateRefundAmountLessThanOrderAmount()) {
				disableRefundButton()
				showElement(smebankRefundAlertExceeds)
			} else if (!validateRefundAmountMoreThanZero()) {
				disableRefundButton()
				showElement(smebankRefundAlertZero)
			} else {
				enableRefundButton();
				updateSmebankRefundAmount();
				showElement(smebankRefundAmountWarning)
			}
		}

		function showElement(element) {
			element.css('display','block');
		}

		function hideElement(element) {
			element.css('display','none');
		}

		function updateSmebankRefundAmount() {
			amount = calculateRefundAmount().toFixed(2);
			smebankRefundAmountWarningSpan.text(amount+' '+smebank_order_currency);
			smebankRefundAmountInput.val(amount);
		}

		function validateRefundAmountLessThanOrderAmount() {
			return getMaxAvailableRefundAmount() >= calculateRefundAmount();
		}

		function validateRefundAmountMoreThanZero() {
			return calculateRefundAmount() > 0;
		}

		function calculateRefundAmount() {
			var refundAmount = 0;
			prestashopPartialRefundProductInputs.each(function () {
				var value = $(this).val()
				if (value) {
					refundAmount += parseFloat(value);
				}
			})

			refundAmount += parseFloat(prestashopPartialRefundShippingCostInput.val())

			return refundAmount;
		}

		function getOrderTotal() {
			return parseFloat(smebank_order_total);
		}

		function getMaxAvailableRefundAmount() {
			return parseFloat(smebank_max_refund_amount);
		}

		function disableRefundButton() {
			prestashopRefundButton.prop('disabled',true);
		}

		function enableRefundButton() {
			prestashopRefundButton.prop('disabled',false);
		}
	});
} catch (error) {
	console.log(error);
}

function getRefundSmebankSectionHtmlPre176() {
	var html = '<p class="checkbox">';
	html += '<label for="refundwithsmebank">';
	html += '<input type="checkbox" id="refundwithsmebank" name="refundwithsmebank">';
	html += '<input type="hidden" id="refundwithsmebank-amount" name="refundwithsmebank-amount">';
	html += '<input type="hidden" id="refundwithsmebank-token" name="refundwithsmebank-token" value="'+ smebank_refund_form_token +'">';
	html += '<strong>' + smebank_text + '</strong>';
	html += '</label>';
	html += '</p>';
	html += getSmebankAlertDivs();

	return html;
}

function getRefundSmebankSectionHtmlPost176()
{
	var html = `<div class="cancel-product-element form-group smebank-refund" style="display: block;">`;
		html+=	`<div class="checkbox">
					<div class="md-checkbox md-checkbox-inline">
						<label for="refundwithsmebank">
						<input type="checkbox" id="refundwithsmebank" name="refundwithsmebank" class="cancel_product_restock" material_design="material_design">
							<i class="md-checkbox-control"></i>`+smebank_text+`</label>`
		html += '<input type="hidden" id="refundwithsmebank-amount" name="refundwithsmebank-amount">';
		html += '<input type="hidden" id="refundwithsmebank-token" name="refundwithsmebank-token" value="'+ smebank_refund_form_token +'">';
		html += `</div>`
		html += `</div>`
		html += getSmebankAlertDivs();
		html += `</div>`;

	return html;
}

function getSmebankAlertDivs()
{
	var html = '<div class="alert alert-danger" id="smebank-refund-alert-exceeds" style="display: none;">'+smebank_refund_exceeds_text+'</div>'
	html += '<div class="alert alert-danger" id="smebank-refund-alert-zero" style="display: none;">'+smebank_refund_zero_text+'</div>'
	html += '<div class="alert alert-warning" id="smebank-refund-amount-warning" style="display: none;">'+smebank_refund_amount_text + ' <span id="smebank-refund-amount-warning-span"></span></div>'
	return html;
}